import { DEVICE_DICT } from '~/src/helpers.js';

function isMobile(a) {
    return /Mobile|Android|iP(hone|od)|IEMobile|BlackBerry|Kindle|Silk-Accelerated|(hpw|web)OS|Opera M(obi|ini)/.test(a); // eslint-disable-line
}

function isTablet(a) {
    return /(tablet|ipad|playbook|silk)|(android(?!.*mobi))/i.test(a); // eslint-disable-line
}

export function getDeviceFromUA(ua) {
    if (isMobile(ua)) {
        return DEVICE_DICT.MOBILE;
    } else if (isTablet(ua)) {
        return DEVICE_DICT.TABLET;
    } else {
        return DEVICE_DICT.DESKTOP;
    }
}

export function getDeviceFromBreakpoints(container, breakpoints) {
    const { width } = container.getBoundingClientRect();

    const keys = Object.keys(breakpoints);
    const values = Object.values(breakpoints);

    const reversedBreakpoints = keys.reduce((acc, key) => ({
        ...acc,
        [breakpoints[key]]: key,
    }), {});

    const minBreakpoint = values.reduce((last, current) => width <= current && current < last ? current : last, values[values.length - 1]);

    return reversedBreakpoints[minBreakpoint];
}
