import Vue from 'vue';

import { defaultOptions, DEVICE_DICT } from '~/src/helpers.js';
import { getDeviceFromUA, getDeviceFromBreakpoints } from '~/src/getDevice';


const nuxtDevice = (req, userOptions = {}) => Vue.extend({
    data() {
        const breakpoints = {
            ...defaultOptions,
            ...userOptions,
        };

        return {
            breakpoints,

            state: getDeviceFromUA(req ? req.headers['user-agent'] : window.navigator.userAgent),
            isInited: false,
        };
    },

    created() {
        if (!req) {
            this.initClientSide();
        }
    },

    computed: {
        is() {
            return (...args) => args.includes(this.state);
        },

        isMobile() {
            return this.state === DEVICE_DICT.MOBILE;
        },

        isTablet() {
            return this.state === DEVICE_DICT.TABLET;
        },

        isLaptop() {
            return this.state === DEVICE_DICT.LAPTOP;
        },

        isDesktop() {
            return this.state === DEVICE_DICT.DESKTOP;
        },
    },

    methods: {
        initClientSide() {
            const setDevice = () => {
                const result = getDeviceFromBreakpoints(document.body, this.breakpoints);

                if (this.state === result) {
                    return false;
                }

                this.state = result;
            };

            let timerId;

            function throttle(timing, callback) {
                if (timerId) {
                    return;
                }

                timerId = setTimeout(function() {
                    timerId = undefined;
                    setDevice();

                    if (callback) {
                        callback();
                    }
                }, timing || 100);
            }

            throttle(250, () => {
                document.body.style.opacity = null;

                if (!this.$nuxt.$options.head) {
                    this.$nuxt.$options = {};
                }

                if (!this.$nuxt.$options.head.bodyAttrs) {
                    this.$nuxt.$options.head.bodyAttrs = {};
                }

                const bodyStyle = this.$nuxt.$options.head.bodyAttrs.style || '';
                this.$nuxt.$options.head.bodyAttrs.style = bodyStyle.replace(/opacity:\s?\.?\d*;?/g, '');
            });

            window.addEventListener('resize', throttle);
        },
    },
});

export default nuxtDevice;
